@@ -12,25 +12,34 @@ class BaseRepository(implements(InterfaceBaseRepository)):
 
     def execute_query(
             self,
-            query: Query | T,
-    ) -> list[T] | T:
+            query: Query,
+    ) -> list[T]:
         """
         Выполнение запроса
         """
-        if isinstance(query, Query):
-            items: T = query.firebase_query.get()
-            return [
-                self.model(id=item.id, **item._data)
-                for item in items
-            ]
-        else:
-            item: T = query
-            return self.model(id=item.id, **item._data)
+        items: T = query.firebase_query.get()
+        return [
+            self.model(id=item.id, **item._data)
+            for item in items
+        ]
+
+    def execute_query_raw(
+            self,
+            query: Query,
+    ) -> list[dict]:
+        """
+        Выполнение запроса без преобразования к объектам
+        """
+        items: T = query.firebase_query.get()
+        return [
+            {id: item.id, **item._data}
+            for item in items
+        ]
 
     def get_by_id(
             self,
             item_id: str
-    ) -> Query:
+    ) -> T:
         """
         Получение по id
         """
