@@ -7,14 +7,20 @@ from fireorm_repository.types.types import T
 class InterfaceBaseRepository(Interface):
     def execute_query(
             self,
-            query: Query | T,
-    ) -> list[T] | T:
+            query: Query,
+    ) -> list[T]:
+        pass
+
+    def execute_query_raw(
+            self,
+            query: Query,
+    ) -> list[dict]:
         pass
 
     def get_by_id(
             self,
             item_id: str
-    ) -> Query:
+    ) -> T:
         pass
 
     def get_by_field(
